<?php
/*******************************************************************************
*    myMVC - Model-View-Controller for PHP                                     *
*    Copyright (C) 2012 Luca Bertoncello                                       *
*    Hartigstrasse, 12 - 01127 Dresden Deutschland                             *
*    E-Mail: lucabert@lucabert.de, lucabert@lucabert.com                       *
*    http://www.lucabert.de/  http://www.lucabert.com/                         *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU Lesser General Public License as published  *
*    by the Free Software Foundation; version 2.1 of the License.              *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU Lesser General Public License for more details.                       *
*                                                                              *
*    You should have received a copy of the GNU Lesser General Public License  *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************/

/**
 * Generic class for a user, that can log into
 * the system.
 * Users should derive this class to manage the
 * users in the database (or other systems)
 */
abstract class myMVC_BaseLogin extends myMVC_BaseDB
{
  /**
   * Allowed chars used to generate a new password
   */
  protected static $passwordAllowedChars = "0123456789bBcCdDfFgGhHjJkKmMnNpPqQrRsStTvVwWxXyYzZ-";

  /**
   * Generate a new password
   * 
   * @param int $lenght                         Length of the password (default: 8)
   * @return string                             The generated password
   */
  public static function generatePassword($length = 8)
  {
    $password = "";
  
    for($i = 0; $i < $length;)
    {
      $char = substr(self::$passwordAllowedChars, mt_rand(0, strlen(self::$passwordAllowedChars) - 1), 1);
      if(!strstr($password, $char))
      {
        $password .= $char;
        $i++;
      }
    }
  
    return $password;
  }

  /**
   * Check the given password against the saved and returns, if it is correct.
   * 
   * @param string $passwd                      User's given password
   * @return boolean                            true if the password was correct, false otherwise
   */
  abstract public function isPasswordCorrect($passwd);
}
?>
