<?php
/*******************************************************************************
*    myMVC - Model-View-Controller for PHP                                     *
*    Copyright (C) 2012 Luca Bertoncello                                       *
*    Hartigstrasse, 12 - 01127 Dresden Deutschland                             *
*    E-Mail: lucabert@lucabert.de, lucabert@lucabert.com                       *
*    http://www.lucabert.de/  http://www.lucabert.com/                         *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU Lesser General Public License as published  *
*    by the Free Software Foundation; version 2.1 of the License.              *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU Lesser General Public License for more details.                       *
*                                                                              *
*    You should have received a copy of the GNU Lesser General Public License  *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************/

/**
 * Generic page class. myMVC_BaseAction and myMVC_BaseView
 * are derived from this class.
 */
class myMVC_BasePage
{
  /**
   * Constructor.
   * This function does <b>nothing</b>!
   * This class will <b>not</b> be used, but just
   * derived (see myMVC_BaseAction and myMVC_BaseView) 
   */
  public function __construct()
  {
  }

  /**
   * Returns the current logged user, if any.
   * This function has to be static, then it will normally
   * called from static functions (eg hasUserRightForAction).
   * 
   * @return myMVC_BaseLogin        The currently logged user, or NULL
   *                                if no user is logged in, or the user's
   *                                class is not a subclass of myMVC_BaseLogin
   */
  protected static function getLoggedUser()
  {
    $session = myMVC_HttpSession::getInstance();
    $user = $session->getFromNamespace('LOGIN', 'loggedUser');
    if($user !== NULL && is_subclass_of($user, 'myMVC_BaseLogin'))
      return $user;
    return NULL;
  }

  /**
   * Save a variable in the session, to be used by the next page (Action or view).
   * This variable can be read with the method getParameterFromPreviousPage
   * of the classes BaseAction or BaseView
   * 
   * @param string $key             The name of the variable
   * @param string $value           The value
   */
  protected function saveParameterForNextPage($key, $value)
  {
    $session = myMVC_HttpSession::getInstance();
    $class = myMVC_Controller::getCurrentAction();
    $session->setInNamespace('MVCRESPONSE-'.$class, $key, $value);
  }

  /**
   * Returns a variable saved from the previous class with saveParameterForNextPage
   * 
   * @param string $key             The name of the variable
   */
  protected function getParameterFromPreviousPage($key)
  {
    $session = myMVC_HttpSession::getInstance();
    $class = myMVC_Controller::getCurrentAction();
    return $session->getFromNamespace('MVCRESPONSE-'.$class, $key);
  }

  /**
   * Returns the value for the given field in the previous submitted form.
   * WARNING: This function just returns the fields, that passed the validation!!
   */
  protected function getFromPreviousSubmit($field)
  {
    $session = myMVC_HttpSession::getInstance();
    $traces = debug_backtrace();
    $caller = $traces[1]['class'];
// The Views must see all given inputs, to allow a review of them.
// The Actions, on the other hand, should just see valid inputs!
    if(is_subclass_of($caller, 'myMVC_BaseView'))
      $fields = $session->getFromNamespace('MVCSAVEDFIELDS', 'allFields');
    else
      $fields = $session->getFromNamespace('MVCSAVEDFIELDS', 'fieldsValid');
    return $fields[$field];
  }

  /**
   * Returns the value for the given field in the previous submitted form.
   * WARNING: This function just returns the fields, that NOT passed the validation!!
   */
  protected function getInvalidFromPreviousSubmit($field)
  {
    $session = myMVC_HttpSession::getInstance();
    $fields = $session->getFromNamespace('MVCSAVEDFIELDS', 'fieldsInvalid');
    return $fields[$field];
  }

  /**
   * Returns whether the given parameter of the previous submitted form
   * passed the validation or not.
   * 
   * @param string $field           The name of the parameter
   * @return bool                   true if the parameter passed the validation, false otherwise
   */
  protected function isParameterFromPreviousSubmitValid($field)
  {
    $session = myMVC_HttpSession::getInstance();
    $traces = debug_backtrace();
    $caller = $traces[1]['class'];
// The Views must see all given inputs, to allow a review of them.
// The Actions, on the other hand, should just see valid inputs!
    if(is_subclass_of($caller, 'myMVC_BaseView'))
      return in_array($field, array_keys($session->getFromNamespace('MVCSAVEDFIELDS', 'allFields')));
    else
      return in_array($field, array_keys($session->getFromNamespace('MVCSAVEDFIELDS', 'fieldsValid')));
  }

  /**
   * Returns all error messages after the validation of the user's parameters
   * 
   * @return array                  An associative array with all the errors in the format
   *                                'field' => 'error message'
   */
  protected function getParameterErrors()
  {
    $session = myMVC_HttpSession::getInstance();
    return $session->getFromNamespace('FORMCHECK', 'ERRORS');
  }
}
?>
